@@ -19,31 +19,33 @@ debug = ndebug.create(__name__)
 
 def get_current_version_by_tag() -> str:
     """
-    Finds the current version of the package in the current working directory.
-    Check tags rather than config file. return 0.0.0 if fails
+    Find the current version of the package in the current working directory using git tags.
 
-    :return: A string with the version number.
+    :return: A string with the version number or 0.0.0 on failure.
     """
     debug('get_current_version_by_tag')
     version = get_last_version()
     if version:
         return version
-    debug('no version found, will retun default')
+
+    debug('no version found, will return default')
     return '0.0.0'
 
 
 def get_current_version_by_config_file() -> str:
     """
-    Get current version from the version variable defined in the configuration
+    Get current version from the version variable defined in the configuration.
 
     :return: A string with the current version number
     :raises ImproperConfigurationError: if version variable cannot be parsed
     """
+    # Get the file and variable names from configuration
     debug('get_current_version_by_config_file')
     filename, variable = config.get('semantic_release',
                                     'version_variable').split(':')
     variable = variable.strip()
     debug(filename, variable)
+
     with open(filename, 'r') as fd:
         file_text = fd.read()
         # checks for variable in the format variable=version
@@ -67,7 +69,7 @@ def get_current_version_by_config_file() -> str:
 
 def get_current_version() -> str:
     """
-    Get current version from tag or version variable, depending on configuration
+    Get current version from tag or version variable, depending on configuration.
 
     :return: A string with the current version number
     """
@@ -78,11 +80,11 @@ def get_current_version() -> str:
 
 def get_new_version(current_version: str, level_bump: str) -> str:
     """
-    Calculates the next version based on the given bump level with semver.
+    Calculate the next version based on the given bump level with semver.
 
     :param current_version: The version the package has now.
-    :param level_bump: The level of the version number that should be bumped. Should be a `'major'`,
-                       `'minor'` or `'patch'`.
+    :param level_bump: The level of the version number that should be bumped.
+        Should be `'major'`, `'minor'` or `'patch'`.
     :return: A string with the next version number.
     """
     debug('get_new_version("{}", "{}")'.format(current_version, level_bump))
@@ -93,10 +95,10 @@ def get_new_version(current_version: str, level_bump: str) -> str:
 
 def get_previous_version(version: str) -> Optional[str]:
     """
-    Returns the version prior to the given version.
+    Return the version prior to the given version.
 
     :param version: A string with the version number.
-    :return: A string with the previous version number
+    :return: A string with the previous version number.
     """
     debug('get_previous_version')
     found_version = False
@@ -118,7 +120,7 @@ def get_previous_version(version: str) -> Optional[str]:
 
 def replace_version_string(content, variable, new_version):
     """
-    Given the content of a file, finds the version string and updates it.
+    Given the content of a file, find the version string and updates it.
 
     :param content: The file contents
     :param variable: The version variable name as a string
@@ -130,7 +132,7 @@ def replace_version_string(content, variable, new_version):
         r'\g<1>{0}\g<2>'.format(new_version),
         content
     )
-    # The version string did not chage because above re did not match. Use : instead of =
+    # The version string did not change because above regex did not match. Use : instead of =
     if (new_content == content):
         new_content = re.sub(
             r'({0} ?: ?["\'])\d+\.\d+(?:\.\d+)?(["\'])'.format(variable),
@@ -142,19 +144,23 @@ def replace_version_string(content, variable, new_version):
 
 def set_new_version(new_version: str) -> bool:
     """
-    Replaces the version number in the correct place and writes the changed file to disk.
+    Replace the version number in the correct place and write the changed file to disk.
 
     :param new_version: The new version number as a string.
     :return: `True` if it succeeded.
     """
+    # Read the contents of the file
     filename, variable = config.get(
         'semantic_release', 'version_variable').split(':')
     variable = variable.strip()
     with open(filename, mode='r') as fr:
         content = fr.read()
 
+    # Update the version variable
     content = replace_version_string(content, variable, new_version)
 
+    # Write the update back to the file
     with open(filename, mode='w') as fw:
         fw.write(content)
+
     return True
