@@ -1,4 +1,4 @@
-"""PyPI
+"""Helper for using Twine to upload to PyPI.
 """
 from invoke import run
 
@@ -15,11 +15,11 @@ def upload_to_pypi(
 
     Wheels must already be created and stored at the given path.
 
-    :param path: Path to dist folder
-    :param username: PyPI account username string
-    :param password: PyPI account password string
-    :param skip_existing: Continue uploading files if one already exists. (Only valid when
-         uploading to PyPI. Other implementations may not support this.)
+    :param path: Path to dist folder containing the files to upload.
+    :param username: PyPI account username.
+    :param password: PyPI account password.
+    :param skip_existing: Continue uploading files if one already exists.
+        (Only valid when uploading to PyPI. Other implementations may not support this.)
     """
     if username is None or password is None or username == "" or password == "":
         raise ImproperConfigurationError('Missing credentials for uploading')
